@@ -59,7 +59,8 @@ class ErroneousTestSuite(running_model.TestSuite):
 __patched = False
 
 
-_stdin_data: Optional[Dict[str, str]] = None
+_stdin_data: Optional[Dict[Uri, str]] = None
+_app: Optional[Application] = None
 
 
 def _patch() -> None:
@@ -187,8 +188,9 @@ def _patch() -> None:
 
     def get_file(self: FileReader, source: Union[str, Path, IOBase], accept_text: bool) -> Any:
         path = self._get_path(source, accept_text)
-        if path:
-            if _stdin_data is not None and (data := _stdin_data.get(str(path))) is not None:
+
+        if path and Path(path).is_absolute():
+            if _stdin_data is not None and (data := _stdin_data.get(Uri.from_path(path).normalized())) is not None:
                 if data is not None:
                     return old_get_file(self, data, True)
 
@@ -380,10 +382,14 @@ def discover(app: Application, show_diagnostics: bool, read_from_stdin: bool) ->
     robotcode --profile regression discover tests
     ```
     """
+    global _app
+    _app = app
     app.show_diagnostics = show_diagnostics or app.config.log_enabled
     if read_from_stdin:
         global _stdin_data
-        _stdin_data = from_json(sys.stdin.buffer.read(), Dict[str, str], strict=True)
+        _stdin_data = {
+            Uri(k).normalized(): v for k, v in from_json(sys.stdin.buffer.read(), Dict[str, str], strict=True).items()
+        }
         app.verbose(f"Read data from stdin: {_stdin_data!r}")
 
 
@@ -459,6 +465,7 @@ def handle_options(
         app, by_longname, exclude_by_longname, robot_options_and_args
     )
 
+    diagnostics_logger = DiagnosticsLogger()
     try:
         _patch()
 
@@ -471,7 +478,7 @@ def handle_options(
             ),
             app.config.dry,
             root_folder,
-        ).parse_arguments((*cmd_options, *robot_options_and_args))
+        ).parse_arguments((*cmd_options, "--runemptysuite", *robot_options_and_args))
 
         settings = RobotSettings(options)
 
@@ -480,7 +487,6 @@ def handle_options(
         else:
             LOGGER.unregister_console_logger()
 
-        diagnostics_logger = DiagnosticsLogger()
         LOGGER.register_logger(diagnostics_logger)
 
         if get_robot_version() >= (5, 0):
@@ -519,6 +525,7 @@ def handle_options(
         suite.configure(**settings.suite_config)
 
         collector = Collector()
+
         suite.visit(collector)
 
         return suite, collector, build_diagnostics(diagnostics_logger.messages)
@@ -527,7 +534,7 @@ def handle_options(
         app.echo(str(err))
         app.exit(INFO_PRINTED)
     except DataError as err:
-        LOGGER.error(err)
+        app.error(str(err))
         app.exit(DATA_ERROR)
 
     raise UnknownError("Unexpected error happened.")
